==> pogamut-emohawk-ville-3.5.2-20130819.040212-108-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/process/EatProcessMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.process;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructor;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.process.AbstractProcessMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.utensil.DishwarePlateMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.process.EatProcessReplication;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.process.IEatProcess;

/** Eat process memorization
 * 
 * @author Paletz
 */
public class EatProcessMemorization
	extends AbstractProcessMemorization<EatProcessReplication>
	implements IEatProcess {
	
	protected DishwarePlateMemorization plate;
	
	public EatProcessMemorization(
		final EatProcessReplication object,
		final ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory );
		
		deferredConstructorChainer.addDeferredConstructor(
			new IDeferredConstructor() {
				@Override
				public void construct() {
					DishwarePlateMemorization tmp = (DishwarePlateMemorization) observationMemory.getMemorization( object.getPlate() );
					plate = tmp;
				}
			}
		);
	}

	@Override
	public DishwarePlateMemorization getPlate() {
		return plate;
	}
}

==> pogamut-emohawk-ville-3.5.4-20140114.043709-29-sources.jar: cz/cuni/amis/pogamut/emohawkVille/agent/module/observationMemory/memorization/process/EatProcessMemorization.java <==
package cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.process;

import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructor;
import cz.cuni.amis.pogamut.emohawk.agent.module.observationMemory.IDeferredConstructorChainer;
import cz.cuni.amis.pogamut.emohawkRpgBase.agent.module.observationMemory.memorization.process.AbstractProcessMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.ObservationMemory;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.observationMemory.memorization.item.utensil.DishwarePlateMemorization;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.process.EatProcessReplica;
import cz.cuni.amis.pogamut.emohawkVille.agent.module.replication.image.process.IEatProcess;

/** Eat process memorization
 * 
 * @author Paletz
 */
public class EatProcessMemorization
	extends AbstractProcessMemorization<EatProcessReplica>
	implements IEatProcess {
	
	protected DishwarePlateMemorization plate;
	
	public EatProcessMemorization(
		final EatProcessReplica object,
		final ObservationMemory observationMemory,
		IDeferredConstructorChainer deferredConstructorChainer
	) {
		super( object, observationMemory );
		
		deferredConstructorChainer.addDeferredConstructor(
			new IDeferredConstructor() {
				@Override
				public void construct() {
					DishwarePlateMemorization tmp = (DishwarePlateMemorization) observationMemory.getMemorization( object.getPlate() );
					plate = tmp;
				}
			}
		);
	}

	@Override
	public DishwarePlateMemorization getPlate() {
		return plate;
	}
}
